@@ -2,21 +2,26 @@ rzdata <-
 setRefClass("RzData",
   fields = c("file.path", "data.set.name", "original.name",
              "data.set", "original.data.set", "data.frame",
-             "log",
+             "data.set.subset", "data.frame.subset",
+             "log", "subset.condition", "subset.on",
              "system", "package.version", "encoding", "time"),
   methods = list(
     initialize        = function(...) {
       initFields(...)
-#      data.set.name     <<- NULL
+#      data.set.name    <<- NULL
       original.data.set <<- data.set
       data.frame        <<- suppressWarnings(as.data.frame(data.set))
-#      log               <<- NULL
+#      log              <<- NULL
       system            <<- R.Version()
       package.version   <<- list(Rz = packageVersion("Rz"),
                                  memisc=packageVersion("memisc"),
                                  RGtk2=packageVersion("RGtk2"))
       encoding          <<- localeToCharset()
       time              <<- Sys.time()
+      subset.condition  <<- ""
+      subset.on         <<- FALSE
+      data.set.subset   <<- NULL
+      data.frame.subset <<- NULL
     },
 
     save = function(file){
@@ -89,13 +94,23 @@ setRefClass("RzData",
     },
     
     linkDataFrame     = function(){
-#      if(rzSettings$getUseDataSetObject()){
-#        assign(data.set.name, data.set, envir=.GlobalEnv)
-#      } else {
-#        assign(data.set.name, data.frame, envir=.GlobalEnv)
-#      }
-      assign(paste(data.set.name, ".ds", sep=""), data.set, envir=.GlobalEnv)
-      assign(data.set.name                      , data.frame, envir=.GlobalEnv)
+      if(subset.on & nzchar(subset.condition)){
+        data.set.subset <<- tryCatch(eval(parse(text=paste("subset(data.set, subset=", subset.condition, ")"))), error=function(...) return(FALSE))
+        if(!is.data.set(data.set.subset)){
+          dialog <- gtkMessageDialogNew(rzTools$getWindow(), "destroy-with-parent",
+                                        "error", "close", gettext("Condition of selecting cases is invalid."))
+          dialog$run()
+          dialog$destroy()
+          return(FALSE)
+        }
+        data.frame.subset <<- eval(parse(text=paste("subset(data.frame, subset=", subset.condition, ")")))
+        rzTools$sync(paste(data.set.name, ".ds", sep=""), data.set.subset)
+        rzTools$sync(data.set.name                      , data.frame.subset)
+      } else {
+        rzTools$sync(paste(data.set.name, ".ds", sep=""), data.set)
+        rzTools$sync(data.set.name                      , data.frame)
+      }
+      return(TRUE)
     },
 
     import = function(data){
@@ -123,8 +138,13 @@ setRefClass("RzData",
       val.labs  <- sapply(val.labs, function(x){ifelse(is.null(x), "", paste(x@values, " \"",x@.Data, "\"", sep="", collapse=", "))})
     },
     
-    getSummaries      = function() {
-      summaries   <- lapply(data.set, summary)
+    getSummaries      = function(subset=FALSE) {
+      summaries <- NULL
+      if (subset) {
+        summaries <- lapply(data.set.subset, summary)
+      } else {
+        summaries <- lapply(data.set, summary)        
+      }
       val <- lapply(summaries, as.character)
       lab <- lapply(summaries, names)
       summaies <- sapply(seq_along(val),
@@ -142,8 +162,13 @@ setRefClass("RzData",
                          )
     },
     
-    getSummary = function(row){
-      summary <- summary(data.set[[row]])
+    getSummary = function(row, subset=FALSE){
+      summary <- NULL
+      if (subset) {
+        summary <- summary(data.set.subset[[row]])        
+      } else {
+        summary <- summary(data.set[[row]])
+      }
       lab <- names(summary)
       val <- as.character(summary)
       lnchar <- nchar(sub("", "", lab), type="width") # "sub()" is for removing invalid character.
@@ -156,7 +181,12 @@ setRefClass("RzData",
                        sapply(sapply(vnchar, function(x) rep(" ", x)), paste, collapse=""),
                        val, sep="", collapse="\n")
       return(summary)
+    },
+    
+    getDataSetName = function(){
+      return(data.set.name)
     }
   )
 )
-rzdata$accessors(c("data.set.name", "original.name", "data.set", "data.frame", "file.path"))
+rzdata$accessors(c("data.set.name", "original.name", "data.set", "data.frame", "file.path",
+                   "subset.condition", "subset.on", "data.set.subset", "data.frame.subset"))
